(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.notificationSystemBlock = {
    attach: function (context, settings) {

      once('loadNotifications', '.notification-block', context).forEach(function (element) {
        var $block = $(element);

        // Lazy load data for the notification block.
        var $placeholder = $block.find('.notification-block__placeholder');

        var getEndpoint = drupalSettings.notificationSystem.getEndpointUrl;
        var display_mode = $block.data('notificationblock-display-mode');
        var show_read = $block.data('notificationblock-show-read');

        if (show_read === 'yes') {
          getEndpoint = getEndpoint + '?showRead';
        }

        $.get(getEndpoint, function (data) {

          if (!data) {
            var $content = $block.find('.notification-dropdown__content');
            $block.find('.notification-block__empty').show();
            $content.addClass('is-empty');
          }
          else {
            $block.find('.notification-block__empty').hide();
          }

          $placeholder.before(data).remove();
          Drupal.attachBehaviors($block[0], settings);

          addEventListeners($block);
          updateCounters();
        });
      });

      function addEventListeners($context) {
        var api = this;
        // Mark as Read.
        once('markAsRead', '.notification-markasread-trigger', $context[0]).forEach(function (element) {
          $(element).click(function (e) {
            markAsRead($(this));
          });
        });
      }

      function markAsRead($triggering_element) {
        var $notificationItem = $triggering_element.parents('.notification-item');
        $notificationItem.children('.notification-markasread-trigger').remove();
        if ($notificationItem.hasClass('is-read')) {
          return;
        }

        var markAsReadEndpoint = drupalSettings.notificationSystem.markAsReadEndpointUrl;
        var messageId = $triggering_element.data('message-id');
        markAsReadEndpoint = markAsReadEndpoint.replace('0', messageId);

        $.ajax({
          url: markAsReadEndpoint,
          type: 'GET',
        }).done(function (data) {
          $notificationItem.addClass('is-read');
          updateCounters();
        }).fail(function (data) {
          if (data.responseJSON.hasOwnProperty('message')) {
            console.error('Error while marking notification as read: ' + data.responseJSON.message);
          }
          else {
            console.error('Unknown error while marking notification as read.');
          }
        });
      }

      function updateCounters() {
        $('.notification-block').each(function () {
          var $block = $(this);

          var $counter = $block.find('.notification-counter');
          var count = $block.find('.notification-item:not(.is-read)').length;
          $counter.text('(' + count + ')');

          if (count > 0) {
            $counter.removeClass('is-hidden');
          }
          else {
            $counter.addClass('is-hidden');
          }
        });
      }
    }
  }
})(jQuery, Drupal, drupalSettings);
