<?php

declare(strict_types=1);

namespace Drupal\message_notifications\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\message_notifications\Controller\NotificationController;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Message notifications settings form class.
 */
final class MessageNotificationsSettingsForm extends ConfigFormBase {

  public function __construct(
    protected readonly EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'lms_messages_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [NotificationController::CONFIG_NAME];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(NotificationController::CONFIG_NAME);
    $form['notification_count'] = [
      '#type' => 'number',
      '#title' => $this->t('Notification count'),
      '#description' => $this->t('Number of displayed notifications'),
      '#default_value' => $config->get('notification_count'),
    ];

    $template_options = [];
    foreach ($this->entityTypeManager->getStorage('message_template')->loadMultiple() as $template_id => $template) {
      $template_options[$template_id] = $template->label();
    }

    $form['notification_templates'] = [
      '#tree' => TRUE,
      '#type' => 'checkboxes',
      '#options' => $template_options,
      '#default_value' => $config->get('notification_templates'),
      '#title' => $this->t('Message templates'),
      '#description' => $this->t('Select which message templates should be displayed as notifications.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config(NotificationController::CONFIG_NAME);

    $config->set('notification_count', $form_state->getValue('notification_count'));
    $config->set('notification_templates', \array_filter($form_state->getValue('notification_templates')))->save();

    parent::submitForm($form, $form_state);
  }

}
