<?php

namespace Drupal\message_notifications\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Entity\Display\EntityViewDisplayInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\message\MessageInterface;

/**
 * Hook implementations of this module.
 */
final class NotificationHooks {

  use StringTranslationTrait;

  #[Hook('entity_base_field_info')]
  public function entityBaseFieldInfo(EntityTypeInterface $entity_type): array {
    $fields = [];

    // Add the "Is read" fieeld storage globally to message entity type
    // as it may be used on multiple bundles.
    if ($entity_type->id() === 'message') {
      $fields['is_read'] = BaseFieldDefinition::create('boolean')
        ->setDefaultValue(FALSE);
    }

    return $fields;
  }

  #[Hook('theme')]
  public function theme(): array {
    return [
      'message_notification_block' => [
        'variables' => [
          'notifications' => NULL,
        ],
      ],
      'message_notifications' => [
        'variables' => [
          'content' => $this->t('Loading...'),
          'empty_message' => $this->t("You don't have any notifications."),
        ],
      ],
      'message_notification_item' => [
        'variables' => [
          'id' => NULL,
          'timestamp' => NULL,
          'title' => NULL,
          'body' => '',
          'isRead' => NULL,
        ],
      ],
    ];
  }

  #[Hook('message_view')]
  public function messageView(array &$build, MessageInterface $message, EntityViewDisplayInterface $display, string $view_mode): void {
    // Set message as read if displayed in default view mode.
    if ($view_mode !== 'default') {
      return;
    }

    $message->set('is_read', TRUE)->save();
  }

}
